<template>
  <gree-popup v-model="isShow" position="bottom" @hide="hidePopup">
    <div class="smart-adjust-set-popup">
      <div class="popup-header">
        <!-- <div class="recommended-Keys" v-for="(item, index) in recommendedKeys" :key="index">
          <div :class="{ 'set-gray': isGray }" @click="isGray = !isGray">
            {{ showRecommendedText(item) }}
          </div>
        </div> -->
        <gree-check-group class="recommended-Keys" v-for="(item, index) in recommendedKeys" :key="index" v-model="patterns">
          <gree-check-box :name="item">{{ showRecommendedText(item) }}</gree-check-box>
        </gree-check-group>
      </div>
      <gree-button class="set-button" block round v-text="'一键开启'" @click="onClick" />
    </div>
  </gree-popup>
</template>

<script>
import { Popup, Button, CheckBox, CheckGroup } from 'gree-ui';
import { mapMutations, mapState, mapActions } from 'vuex';
import { types } from '@/store/types';
import { pluginHttp } from '@PluginInterface';

export default {
  name: 'smart-adjust-set-popup',
  components: {
    [Popup.name]: Popup,
    [Button.name]: Button,
    [CheckBox.name]: CheckBox,
    [CheckGroup.name]: CheckGroup
  },
  data() {
    return {
      patterns: [],
      DEBUG: false,
      isShow: false,
      isGray: false,
      recommendedKeys: [],
      sendRecommendedValue: {},
      recommendedType: '',
      TemValue: 0,
      WdSpdValue: 0,
      ModValue: 0
    };
  },
  computed: {
    ...mapState('control', {
      smartAdjustSet: state => state.popup.smartAdjustSet,
      mac: state => state.mac
    })
  },
  mounted() {
    this.recommendedKeys = this.DEBUG ? ['Mod', 'SetTem', 'WdSpd', 'AssHt', 'SvSt', 'Pow', 'Air', 'CleanState', 'Lig', 'StHt', 'Health'] : ''; // 测试数据
  },
  watch: {
    isShow(newVal) {
      !newVal && this.SetPopup({ smartAdjustSet: false });
    },
    smartAdjustSet: {
      handler(newVal) {
        this.isShow = newVal;
        newVal && this.getRecommendFields();
      },
      immediate: true
    }
  },
  methods: {
    ...mapMutations({
      setDataObject: types.SET_DATA_OBJECT,
      setState: types.CONTROL_SET_STATE
    }),
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP'
    }),
    ...mapActions({
      sendData: types.SEND_DATA
    }),
    hidePopup() {
      this.SetPopup({ smartAdjustSet: false });
    },
    getRecommendFields() {
      pluginHttp('/gateway/portrait-recommend/portrait/recommend/personal', '', JSON.stringify({ mac: this.mac }), 'POST', 'iot7', '')
        .then(_res => {
          const res = JSON.parse(_res).data.data;
          this.sendRecommendedValue = res;
          const recommendedKeys = Object.keys(res);
          if (recommendedKeys.includes('SetTem')) {
            this.TemValue = res.SetTem;
          }
          if (recommendedKeys.includes('WdSpd')) {
            this.WdSpdValue = res.WdSpd;
          }
          if (recommendedKeys.includes('Mod')) {
            this.ModValue = res.Mod;
          }
          this.recommendedKeys = recommendedKeys;
          console.log('ssss,', recommendedKeys, this.recommendedKeys, this.TemValue);
        })
        .catch(err => console.error(err));
    },
    showRecommendedText(item) {
      const WdSpdMap = {
        0: '自动风',
        1: '低风',
        2: '中低风',
        3: '中风',
        4: '中高风',
        5: '高风'
      };
      const ModMap = {
        0: '自动',
        1: '制冷',
        2: '除湿',
        3: '送风',
        4: '制热'
      };
      if (item === 'SetTem') {
        return this.TemValue + '℃';
      } else if (item === 'WdSpd') {
        return WdSpdMap[this.WdSpdValue];
      } else if (item === 'Mod') {
        return ModMap[this.ModValue] + '模式';
      } else {
        return this.$language(`recommended.${item}`) + ' : ' + this.getRecommendType(item);
      }
    },
    filtreOrder() {
      this.patterns.forEach(item => {
        this.$delete(this.sendRecommendedValue, item);
      });
    },
    onClick() {
      this.filtreOrder();
      this.sendData(this.sendRecommendedValue);
      this.hidePopup();
      this.patterns = [];
    },
    getRecommendType(item) {
      let result = '';
      this.sendRecommendedValue[item] ? (result = '开') : (result = '关');
      return result;
    }
  }
};
</script>

<style lang="scss">
// .smart-adjust-set-popup {
//   overflow: hidden;
//   width: 100%;
//   // background-color: #fff;
//   padding-bottom: 50px;
//   .popup-header {
//     display: flex;
//     flex-wrap: wrap;
//     justify-content: space-around;
//     .gree-check-base-box {
//       width: 280px;
//       height: 80px;
//       line-height: 80px;
//       font-size: 44px;
//       border: none;
//       padding: 0;
//       text-align: center;
//       background-color: rgba(152, 152, 152, 0.1);
//       border-radius: 40px;
//       margin-top: 45px;
//       margin-bottom: 45px;
//     }
//     .gree-check-base-box.is-checked {
//       opacity: 0.4 !important;
//       color: #989898;
//       .gree-tag {
//         display: none;
//       }
//     }
//     .gray {
//       background-color: gray;
//     }
//   }
//   .set-button {
//     width: 434px;
//     height: 83px;
//     line-height: 89px;
//     text-align: center;
//     font-size: 40px;
//     opacity: 1;
//     color: #fff;
//     background-color: #77a7e0;
//     border-radius: 47px;
//     margin-top: 90px;
//     margin: 0 auto;
//   }
// }
</style>
